@@ -1203,12 +1203,12 @@ def validate(filename, param_map):
 
         if filename.startswith('./roles/ControllerStorageDashboard.yaml'):
             retval |= validate_controller_dashboard(filename, tpl)
-        if filename in ['./roles/ComputeOvsDpdk.yaml',
-                        './roles/ComputeSriov.yaml',
-                        './roles/ComputeOvsDpdkRT.yaml',
-                        './roles/ComputeSriovRT.yaml',
-                        './roles/ComputeHCIOvsDpdk.yaml',
-                        './roles/ComputeVdpa.yaml']:
+
+        if filename.startswith('./roles/ComputeOvsDpdk.yaml') or \
+                filename.startswith('./roles/ComputeSriov.yaml') or \
+                filename.startswith('./roles/ComputeOvsDpdkRT.yaml') or \
+                filename.startswith('./roles/ComputeSriovRT.yaml') or \
+                filename.startswith('./roles/ComputeHCIOvsDpdk.yaml'):
             exclude = [
                 'OS::TripleO::Services::OVNController',
                 'OS::TripleO::Services::ComputeNeutronOvsAgent',
@@ -1245,8 +1245,7 @@ def validate(filename, param_map):
         # definition instead.
         if (filename.startswith('./network_data_') and
                 not filename.endswith(('routed.yaml',
-                                       'undercloud.yaml',
-                                       'default.yaml'))):
+                                       'undercloud.yaml'))):
             result = validate_network_data_file(filename)
             retval |= result
         else:
